@@ -926,7 +926,7 @@ class MariadbClient(AbstractClient):
 
 
     def DescribeUpgradePrice(self, request):
-        """本接口（DescribeUpgradePrice）用于在扩容云数据库实例时，查询扩容的价格。
+        """本接口（DescribeUpgradePrice）用于在扩容云数据库实例时，查询变配的价格。
 
         :param request: Request instance for DescribeUpgradePrice.
         :type request: :class:`tencentcloud.mariadb.v20170312.models.DescribeUpgradePriceRequest`
